Crate clone_solana_unified_scheduler_pool

Crate clone_solana_unified_scheduler_pool 

Transaction scheduling code.

This crate implements 3 solana-runtime traits InstalledScheduler, UninstalledScheduler and InstalledSchedulerPool to provide a concrete transaction scheduling implementation (including executing txes and committing tx results).

At the highest level, this crate takes SanitizedTransactions via its InstalledScheduler::schedule_execution and commits any side-effects (i.e. on-chain state changes) into the associated Bank via solana-ledger’s helper function called execute_batch.

Refer to PooledScheduler doc comment for general overview of scheduler state transitions regarding to pooling and the actual use.

Structs

BankingStageHelper
DefaultTaskHandler
HandlerContext
PooledScheduler
The concrete scheduler instance along with 1 scheduler and N handler threads.
PooledSchedulerInner
SchedulerPool
A pool of idling schedulers (usually PooledScheduler), ready to be taken by bank.
UsageQueueLoader
The primary owner of all UsageQueues used for particular PooledScheduler.

Traits

BankingPacketHandler
SchedulerInner
SpawnableScheduler
TaskHandler

Type Aliases

DefaultSchedulerPool